@@ -138,7 +138,17 @@ class FelderaClient:
                             err_msg += f"Code snippet:\n{sql_error['snippet']}"
                         raise RuntimeError(err_msg)
 
-                raise RuntimeError(f"The program failed to compile: {status}")
+                error_message = f"The program failed to compile: {status}\n"
+
+                rust_error = p.program_error.get("rust_compilation")
+                if rust_error is not None:
+                    error_message += f"Rust Error: {rust_error}\n"
+
+                system_error = p.program_error.get("system_error")
+                if system_error is not None:
+                    error_message += f"System Error: {system_error}"
+
+                raise RuntimeError(error_message)
 
             logging.debug("still compiling %s, waiting for 100 more milliseconds", name)
             time.sleep(0.1)
@@ -952,7 +962,9 @@ Reason: The pipeline is in a STOPPED state due to the following error:
 
         return FelderaConfig(resp)
 
-    def get_pipeline_support_bundle(self, pipeline_name: str) -> bytes:
+    def get_pipeline_support_bundle(
+        self, pipeline_name: str, params: Optional[Dict[str, Any]] = None
+    ) -> bytes:
         """
         Generate a support bundle containing diagnostic information from a pipeline.
 
@@ -961,12 +973,14 @@ Reason: The pipeline is in a STOPPED state due to the following error:
         and packages them into a single ZIP file for support purposes.
 
         :param pipeline_name: The name of the pipeline
+        :param params: Optional query parameters to control data collection
         :return: The support bundle as bytes (ZIP file)
         :raises FelderaAPIError: If the pipeline does not exist or if there's an error
         """
 
         resp = self.http.get(
             path=f"/pipelines/{pipeline_name}/support_bundle",
+            params=params,
             stream=True,
         )
 
